package NN;

use strict;
use warnings;
use base qw(Date::Holidays::Abstract);

1;

